==> haskell-servant-server-0.11-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.11
id: servant-server-0.11-IADlUM83Uj7GUOFTlU9US9
key: servant-server-0.11-IADlUM83Uj7GUOFTlU9US9
license: BSD3
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant Web
author: Servant Contributors
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
abi: 7a4195dae409c120d5e695a05b4ea3bf
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/servant-server-0.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/servant-server-0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/servant-server-0.11
hs-libraries: HSservant-server-0.11-IADlUM83Uj7GUOFTlU9US9
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9
    attoparsec-0.13.1.0-DWdB5NAuEI54zL0UJYXwyo base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    base64-bytestring-1.0.0.1-4O9TExPPz6eI82Yj7L4SIj
    bytestring-0.10.8.1 containers-0.5.7.1
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd filepath-1.4.1.1
    http-api-data-0.3.7.1-6JL4GyjDoptconbqdu8s
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    servant-0.11-HYMhF2TOpgk2xND9WoSH47
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
    string-conversions-0.4.0.1-743WgfuBUTV5Nolj1lMwBa
    system-filepath-0.4.13.4-HlN3n6Ilo5lFhUyRmrYqIK
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-app-static-3.1.6.1-3PShIFu84hMJ9NMtwWy1mg
    warp-3.2.12-JHy0oausRdD30Fa4JNt43k
    word8-0.1.2-9WDPGCTpW7JJnsiAQavtd1
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.11-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.11
id: servant-server-0.11-EgZ3h00gMEt8ggJ2cii7Zg
key: servant-server-0.11-EgZ3h00gMEt8ggJ2cii7Zg
license: BSD3
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant Web
author: Servant Contributors
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
abi: 492da0c77b681e4b5b3a63f04a2d2215
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/servant-server-0.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/servant-server-0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/servant-server-0.11
hs-libraries: HSservant-server-0.11-EgZ3h00gMEt8ggJ2cii7Zg
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    base64-bytestring-1.0.0.1-4O9TExPPz6eI82Yj7L4SIj
    bytestring-0.10.8.1 containers-0.5.7.1
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd filepath-1.4.1.1
    http-api-data-0.3.7.1-3zEe5ySvc6j6xRQh0wfGfT
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    servant-0.11-El9ZNiUW0kX3q13DPeqxkV
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
    string-conversions-0.4.0.1-743WgfuBUTV5Nolj1lMwBa
    system-filepath-0.4.13.4-HlN3n6Ilo5lFhUyRmrYqIK
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-app-static-3.1.6.1-1PkuJxcpqdi5vGsOBEAHu0
    warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
    word8-0.1.2-9WDPGCTpW7JJnsiAQavtd1
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
